#line 1 "src/scan-gram.c"

#line 3 "src/scan-gram.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

/* %not-for-header */
/* %if-c-only */
/* %if-not-reentrant */
#define yy_create_buffer gram__create_buffer
#define yy_delete_buffer gram__delete_buffer
#define yy_scan_buffer gram__scan_buffer
#define yy_scan_string gram__scan_string
#define yy_scan_bytes gram__scan_bytes
#define yy_init_buffer gram__init_buffer
#define yy_flush_buffer gram__flush_buffer
#define yy_load_buffer_state gram__load_buffer_state
#define yy_switch_to_buffer gram__switch_to_buffer
#define yypush_buffer_state gram_push_buffer_state
#define yypop_buffer_state gram_pop_buffer_state
#define yyensure_buffer_stack gram_ensure_buffer_stack
#define yy_flex_debug gram__flex_debug
#define yyin gram_in
#define yyleng gram_leng
#define yylex gram_lex
#define yylineno gram_lineno
#define yyout gram_out
#define yyrestart gram_restart
#define yytext gram_text
#define yywrap gram_wrap
#define yyalloc gram_alloc
#define yyrealloc gram_realloc
#define yyfree gram_free

/* %endif */
/* %endif */
/* %ok-for-header */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* %if-c++-only */
/* %endif */

/* %if-c-only */
#ifdef yy_create_buffer
#define gram__create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer gram__create_buffer
#endif

#ifdef yy_delete_buffer
#define gram__delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer gram__delete_buffer
#endif

#ifdef yy_scan_buffer
#define gram__scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer gram__scan_buffer
#endif

#ifdef yy_scan_string
#define gram__scan_string_ALREADY_DEFINED
#else
#define yy_scan_string gram__scan_string
#endif

#ifdef yy_scan_bytes
#define gram__scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes gram__scan_bytes
#endif

#ifdef yy_init_buffer
#define gram__init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer gram__init_buffer
#endif

#ifdef yy_flush_buffer
#define gram__flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer gram__flush_buffer
#endif

#ifdef yy_load_buffer_state
#define gram__load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state gram__load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define gram__switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer gram__switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define gram_push_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state gram_push_buffer_state
#endif

#ifdef yypop_buffer_state
#define gram_pop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state gram_pop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define gram_ensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack gram_ensure_buffer_stack
#endif

#ifdef yylex
#define gram_lex_ALREADY_DEFINED
#else
#define yylex gram_lex
#endif

#ifdef yyrestart
#define gram_restart_ALREADY_DEFINED
#else
#define yyrestart gram_restart
#endif

#ifdef yylex_init
#define gram_lex_init_ALREADY_DEFINED
#else
#define yylex_init gram_lex_init
#endif

#ifdef yylex_init_extra
#define gram_lex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra gram_lex_init_extra
#endif

#ifdef yylex_destroy
#define gram_lex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy gram_lex_destroy
#endif

#ifdef yyget_debug
#define gram_get_debug_ALREADY_DEFINED
#else
#define yyget_debug gram_get_debug
#endif

#ifdef yyset_debug
#define gram_set_debug_ALREADY_DEFINED
#else
#define yyset_debug gram_set_debug
#endif

#ifdef yyget_extra
#define gram_get_extra_ALREADY_DEFINED
#else
#define yyget_extra gram_get_extra
#endif

#ifdef yyset_extra
#define gram_set_extra_ALREADY_DEFINED
#else
#define yyset_extra gram_set_extra
#endif

#ifdef yyget_in
#define gram_get_in_ALREADY_DEFINED
#else
#define yyget_in gram_get_in
#endif

#ifdef yyset_in
#define gram_set_in_ALREADY_DEFINED
#else
#define yyset_in gram_set_in
#endif

#ifdef yyget_out
#define gram_get_out_ALREADY_DEFINED
#else
#define yyget_out gram_get_out
#endif

#ifdef yyset_out
#define gram_set_out_ALREADY_DEFINED
#else
#define yyset_out gram_set_out
#endif

#ifdef yyget_leng
#define gram_get_leng_ALREADY_DEFINED
#else
#define yyget_leng gram_get_leng
#endif

#ifdef yyget_text
#define gram_get_text_ALREADY_DEFINED
#else
#define yyget_text gram_get_text
#endif

#ifdef yyget_lineno
#define gram_get_lineno_ALREADY_DEFINED
#else
#define yyget_lineno gram_get_lineno
#endif

#ifdef yyset_lineno
#define gram_set_lineno_ALREADY_DEFINED
#else
#define yyset_lineno gram_set_lineno
#endif

#ifdef yywrap
#define gram_wrap_ALREADY_DEFINED
#else
#define yywrap gram_wrap
#endif

/* %endif */

#ifdef yyalloc
#define gram_alloc_ALREADY_DEFINED
#else
#define yyalloc gram_alloc
#endif

#ifdef yyrealloc
#define gram_realloc_ALREADY_DEFINED
#else
#define yyrealloc gram_realloc
#endif

#ifdef yyfree
#define gram_free_ALREADY_DEFINED
#else
#define yyfree gram_free
#endif

/* %if-c-only */

#ifdef yytext
#define gram_text_ALREADY_DEFINED
#else
#define yytext gram_text
#endif

#ifdef yyleng
#define gram_leng_ALREADY_DEFINED
#else
#define yyleng gram_leng
#endif

#ifdef yyin
#define gram_in_ALREADY_DEFINED
#else
#define yyin gram_in
#endif

#ifdef yyout
#define gram_out_ALREADY_DEFINED
#else
#define yyout gram_out
#endif

#ifdef yy_flex_debug
#define gram__flex_debug_ALREADY_DEFINED
#else
#define yy_flex_debug gram__flex_debug
#endif

#ifdef yylineno
#define gram_lineno_ALREADY_DEFINED
#else
#define yylineno gram_lineno
#endif

/* %endif */

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
/* %if-c-only */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>
/* %endif */

/* %if-tables-serialization */
/* %endif */
/* end standard C headers. */

/* %if-c-or-c++ */
/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* %endif */

/* begin standard C++ headers. */
/* %if-c++-only */
/* %endif */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* %not-for-header */
/* Returned upon end-of-file. */
#define YY_NULL 0
/* %ok-for-header */

/* %not-for-header */
/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))
/* %ok-for-header */

/* %if-reentrant */
/* %endif */

/* %if-not-reentrant */

/* %endif */

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

/* %if-not-reentrant */
extern int yyleng;
/* %endif */

/* %if-c-only */
/* %if-not-reentrant */
extern FILE *yyin, *yyout;
/* %endif */
/* %endif */

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
/* %if-c-only */
	FILE *yy_input_file;
/* %endif */

/* %if-c++-only */
/* %endif */

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* %if-c-only Standard (non-C++) definition */
/* %not-for-header */
/* %if-not-reentrant */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */
/* %endif */
/* %ok-for-header */

/* %endif */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* %if-c-only Standard (non-C++) definition */

/* %if-not-reentrant */
/* %not-for-header */
/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;
/* %ok-for-header */

/* %endif */

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

/* %endif */

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* %% [1.0] yytext/yyin/yyout/yy_state_type/yylineno etc. def's & init go here */
/* Begin user sect3 */

#define gram_wrap() (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP

#define FLEX_DEBUG
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

/* %% [1.5] DFA */

/* %if-c-only Standard (non-C++) definition */

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* %endif */

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
/* %% [2.0] code to fiddle yytext and yyleng for yymore() goes here \ */\
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
/* %% [3.0] code to copy yytext_ptr to yytext[] goes here, if %array \ */\
	(yy_c_buf_p) = yy_cp;
/* %% [4.0] data tables for the DFA and the user's section 1 definitions go here */
#define YY_NUM_RULES 131
#define YY_END_OF_BUFFER 132
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[606] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   92,   92,  115,  115,  115,  115,
        0,    0,    0,    0,  132,   79,    2,    2,    2,   69,
       79,   68,   79,    1,   64,   79,   65,   65,   60,   63,
       76,   61,   64,   78,   64,   72,   62,   79,   89,   89,
       89,  130,  130,   98,  130,   97,  114,  130,  130,  130,
      130,  130,  130,  130,   80,   94,   93,   96,  130,   83,
        2,    2,    1,   83,   82,   81,   83,  100,  100,  101,
       99,   80,  121,  130,  120,  130,  130,  130,  124,  127,

      128,  130,   91,  130,  130,  119,  130,  118,  130,  117,
      130,  116,   86,    2,    2,    1,   84,   86,   86,   85,
       86,   87,    2,    2,    1,   87,   87,   79,    2,   77,
       59,    0,   59,   59,   59,   59,   59,   59,   59,   59,
       59,   59,   59,   59,   59,   59,   59,   59,   59,   59,
       71,   64,   64,    4,    3,   67,   65,   67,    0,   75,
        0,    0,   89,   88,   98,  113,  113,  111,  102,  113,
      104,  105,  106,  107,  108,  109,  113,  110,  113,  130,
        0,    0,    0,    0,    0,    0,   95,  100,  100,  101,
      129,  122,  123,    0,  125,    0,  124,  126,    0,   90,

        0,   91,    0,   92,    0,  119,  115,  115,  115,  115,
      115,  117,   86,   84,   59,    0,    0,   73,   59,   59,
       59,   59,   59,   59,   59,   59,   59,   59,   59,   59,
       59,   59,   59,   59,   59,   59,   59,   59,   59,   59,
       59,   59,   59,   59,   59,   59,   59,   59,   59,    3,
       67,   66,   74,   70,    0,  102,    0,    0,  103,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,   59,   59,   59,   59,   59,   59,   59,   59,   59,
       59,   59,   59,   59,   59,   59,   59,   59,   59,   59,

       59,   59,   59,   59,   59,   59,   59,   59,   59,   59,
       59,   59,   59,   59,   59,   59,   59,   59,   59,    0,
      102,    0,    0,   59,    7,   59,   59,   59,   59,   59,
       59,   59,   59,   59,   59,   59,   59,   59,   21,   59,
       59,   59,   59,   59,   59,   59,   59,   59,   59,   59,
       59,   59,   59,   33,   59,   59,   59,   59,   59,   59,
       40,   59,   43,   59,   59,   46,    0,    0,    0,   59,
        8,   59,   59,   59,   13,   14,   59,   59,   59,   59,
       59,   59,   59,   59,   59,   24,   59,   59,   59,   59,
       59,   59,   59,   29,   59,   31,   59,   59,   59,   59,

       59,   37,   59,   39,   41,   44,   59,    0,    0,  112,
        6,   59,   10,   59,   59,   59,   15,   59,   59,   59,
       59,   59,   59,   59,   59,   59,   59,   59,   59,   59,
       59,   30,   59,   59,   59,   59,   59,   59,   59,   59,
       59,    0,   59,   11,   59,   59,   59,   59,   59,   59,
       59,   59,   59,   59,   59,   59,   59,   59,   59,   59,
       59,   59,   59,    0,   57,   59,   59,   35,   59,   36,
       59,   59,   59,   45,    5,    0,    0,   59,   59,   59,
       59,   59,   59,   59,   59,   59,   59,   59,   20,   59,
       59,   59,   59,   26,   59,   56,   27,   59,   59,   59,

       59,   38,   59,   59,    0,   59,   59,   59,   59,   59,
       16,   52,   59,   59,   59,   59,   22,   23,   59,   59,
       59,   59,   59,   59,   59,   59,   59,    0,    0,   59,
       59,   12,   59,   59,   59,   59,   19,   59,   59,   59,
       59,   59,   59,   34,   59,   59,   59,    0,   59,   59,
       59,   59,   17,   59,   59,   49,   59,   59,   59,   32,
       47,   42,   58,    9,   50,   59,   59,    0,   53,   59,
       59,   49,   49,   59,   59,   59,   48,   51,   59,   59,
       49,   59,   59,   59,   59,   18,   59,   59,   59,   59,
       25,   55,   59,   59,   59,   59,   59,   54,   59,   59,

       59,   59,   59,   28,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        4,    4,    5,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    6,    7,    8,    9,    7,   10,    7,   11,   12,
       13,   14,    7,   15,   16,   17,   18,   19,   20,   20,
       20,   20,   20,   20,   20,   21,   21,   22,   23,   24,
       25,   26,   27,   28,   29,   29,   29,   29,   29,   29,
       30,   30,   30,   30,   30,   30,   30,   30,   30,   30,
       30,   30,   30,   30,   31,   30,   30,   32,   30,   30,
       33,   34,   35,   28,   36,   28,   37,   38,   39,   40,

       41,   42,   43,   44,   45,   30,   46,   47,   48,   49,
       50,   51,   52,   53,   54,   55,   56,   57,   30,   58,
       59,   30,   60,   61,   62,   28,   63,   64,   64,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,
       64,   64,   64,   65,   65,   65,   65,   65,   65,   65,
       65,   65,   65,   65,   65,   65,   65,   65,   65,   66,
       66,   66,   66,   66,   66,   66,   66,   66,   66,   66,
       66,   66,   66,   66,   66,   66,   66,   66,   66,   66,
       66,   66,   66,   66,   66,   66,   66,   66,   66,   66,
       66,    1,    1,   67,   67,   67,   67,   67,   67,   67,

       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   68,   69,   69,   69,   69,   69,   69,
       69,   69,   69,   69,   69,   69,   70,   69,   69,   71,
       72,   72,   72,   73,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[75] =
    {   0,
        1,    2,    3,    2,    2,    2,    1,    4,    1,    4,
        4,    1,    1,    4,    4,    5,    6,    2,    7,    7,
        7,    8,    9,   10,    9,   10,    8,    8,    7,    7,
        7,    7,   11,    8,   12,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    9,
        9,    9,    8,    8,    8,    8,    1,    1,    1,    1,
        1,    1,    1,    8
    } ;

static const flex_int16_t yy_base[624] =
    {   0,
        0, 1357,   70,   71,   85,  159,   89,   90,   99,  100,
      110,  163,  105,  110,  172,  184,  231,  242,  251,  269,
      289,  316,  303,  325,  204,  209,  307,  349,  350,  353,
      427, 1356,  195,  364, 1364,    0, 1367, 1367, 1360, 1367,
      492, 1367, 1367, 1367,  552,   63,   59,  103,    0, 1367,
       73, 1367,    0, 1367, 1350, 1367, 1367, 1314, 1367, 1357,
     1341, 1367, 1367, 1367, 1355, 1367,  622,   73, 1291,   76,
       18,    0,   80, 1292, 1367, 1367, 1367, 1367, 1342, 1367,
     1367, 1351, 1367,  190, 1367, 1367, 1306, 1336,  104, 1327,
     1367, 1334, 1367, 1287, 1367,  203,  101,  137, 1367, 1367,

     1367,  185, 1367, 1345,  342, 1367, 1344, 1367,  391, 1367,
     1343, 1367,    0, 1367, 1342,    0,    0,  226, 1367, 1367,
     1297, 1367, 1367, 1340, 1367,  243, 1295,    0, 1367, 1367,
        0,  502, 1296, 1290,  135,  215, 1294, 1291, 1288,  234,
     1295,  283, 1279,  211,  241,   63,  229, 1285, 1292, 1295,
     1367,    0,    0, 1367,    0,    0,  381,  647, 1305, 1367,
     1322, 1284, 1367, 1367, 1367, 1367, 1325, 1367,  154,  653,
     1367, 1367, 1367, 1367, 1367, 1367,  677, 1367,  683, 1367,
      339,  342,  345,  348,  351,  354, 1367, 1311,  285, 1302,
     1367, 1367, 1367,  508, 1367,  552, 1367, 1367,  632, 1367,

      641, 1367,  705, 1291, 1321, 1367, 1367,  724, 1289, 1319,
      729, 1367,    0,    0,    0,  734, 1318, 1367, 1271, 1279,
      616, 1265, 1266, 1263, 1264,  158, 1261, 1268, 1263,  193,
     1272, 1257, 1261,  273, 1267, 1252, 1253,  290, 1252, 1252,
     1260, 1261, 1264, 1247, 1253, 1247, 1252, 1243, 1256,    0,
        0,    0, 1367, 1367, 1245,  276,  722,  728,  758,  451,
      461,  511,  750,  357, 1290,  769,  264, 1289,  778,  364,
     1288,  786,  594, 1287,  799,  804, 1286,  809,  814,  628,
     1285, 1250, 1245, 1229,  335, 1229, 1242, 1227, 1231, 1239,
     1238, 1237, 1261, 1221, 1232, 1219, 1257, 1235, 1228, 1229,

      345,  520,  151, 1216, 1217,  466, 1228, 1217, 1224, 1208,
     1219, 1215, 1208, 1212, 1218, 1217, 1207, 1218, 1216, 1213,
     1367,  802,  808, 1200,    0, 1209, 1195, 1201, 1196, 1209,
     1188, 1193, 1206, 1228, 1203, 1191, 1196, 1184,    0, 1188,
     1183, 1196,  326, 1195, 1190, 1193, 1188, 1178, 1190, 1182,
     1173, 1180, 1186, 1185, 1170,  616, 1179, 1168, 1181, 1166,
        0, 1171,    0, 1170, 1168,    0, 1211,  832,  838, 1157,
        0, 1168, 1173, 1157,    0,    0,  645, 1157, 1160,  647,
     1173, 1172, 1171, 1170, 1161,    0, 1154, 1162, 1154, 1160,
     1152, 1146, 1144,    0, 1143,    0, 1181, 1156, 1154, 1143,

     1140,    0, 1137,    0,  818,    0, 1137,  680,  862, 1367,
        0, 1135, 1135, 1149, 1130, 1129,  819, 1132, 1134, 1130,
     1135, 1138, 1127, 1129, 1125, 1140, 1135, 1138, 1133, 1123,
     1131,  860, 1120, 1129, 1116, 1131, 1126, 1116, 1110, 1109,
     1122,  887,  820,    0, 1107, 1120, 1119, 1106, 1105, 1116,
     1100, 1101, 1138, 1112, 1115, 1102, 1109, 1093, 1094, 1091,
     1092, 1106, 1091,  892, 1367, 1106, 1093,    0, 1088,    0,
     1091, 1102, 1101,    0, 1367, 1134, 1128, 1084, 1083, 1083,
     1079, 1078, 1077, 1076, 1086, 1072, 1085, 1088,    0, 1076,
     1069, 1080, 1074,    0, 1073,    0,    0, 1062, 1042, 1043,

     1027,    0, 1040, 1039, 1055,  976,  975,  974,  987,  984,
        0,    0,  976,  969,  904,  917,    0,    0,  910,  893,
      892,  895,  896,  890,  883,  876,  869,  907,  881,  846,
      819,    0,  788,  783,  774,  774,    0,  771,  767,  852,
      889,  775,  745,    0,  733,  744,  735,  418,  719,  711,
      692,  691,  907,  689,  668,  916,  654,  618,  620,    0,
        0,    0,    0,    0,    0,  616,  614,  924, 1367,  898,
      601,  933,  940,  597,  595,  586,    0,    0,  597,  580,
      948,  573,  572,  530,  533,    0,  531,  527,  518,  471,
        0,    0,  383,  348,  370,  311,  281,    0,  292,  228,

      157,   92,   53,    0, 1367,  958,  970,  982,  994, 1006,
     1018, 1025, 1028, 1035, 1041, 1053, 1065, 1075, 1082, 1085,
     1092, 1100, 1107
    } ;

static const flex_int16_t yy_def[624] =
    {   0,
      605,    1,  606,  606,  607,  607,    6,    6,    6,    6,
      608,  608,  609,  609,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
      605,   31,  610,  610,  605,  611,  605,  605,  605,  605,
      605,  605,  605,  605,  605,  605,  612,  612,  611,  605,
      605,  605,  613,  605,  613,  605,  605,  611,  605,  605,
      605,  605,  605,  605,  605,  605,  614,  605,  605,  605,
      605,  615,  605,  605,  605,  605,  605,  605,  605,  605,
      605,  605,  605,  605,  605,  605,  605,  616,  616,  605,
      605,  616,  605,  605,  605,  605,  605,  605,  605,  605,

      605,  605,  605,  605,  605,  605,  605,  605,  617,  605,
      605,  605,  618,  605,  605,  618,  619,  605,  605,  605,
      618,  605,  605,  605,  605,  605,  605,  611,  605,  605,
      620,  605,  620,  620,  620,  620,  620,  620,  620,  620,
      620,  620,  620,  620,  620,  620,  620,  620,  620,  620,
      605,   45,  613,  605,  621,  622,  612,  622,  605,  605,
      605,  605,  605,  605,  605,  605,  605,  605,  605,  605,
      605,  605,  605,  605,  605,  605,  605,  605,  605,  605,
      605,  605,  605,  605,  605,  605,  605,  616,  616,  605,
      605,  605,  605,  605,  605,  605,  605,  605,  605,  605,

      605,  605,  605,  605,  605,  605,  605,  605,  605,  605,
      605,  605,  618,  619,  620,  605,  605,  605,  620,  620,
      620,  620,  620,  620,  620,  620,  620,  620,  620,  620,
      620,  620,  620,  620,  620,  620,  620,  620,  620,  620,
      620,  620,  620,  620,  620,  620,  620,  620,  620,  621,
      622,  158,  605,  605,  605,  605,  605,  605,  605,  605,
      605,  605,  605,  605,  605,  605,  605,  605,  605,  605,
      605,  605,  605,  605,  605,  605,  605,  605,  605,  617,
      605,  620,  620,  620,  620,  620,  620,  620,  620,  620,
      620,  620,  620,  620,  620,  620,  620,  620,  620,  620,

      620,  620,  620,  620,  620,  620,  620,  620,  620,  620,
      620,  620,  620,  620,  620,  620,  620,  620,  620,  605,
      605,  605,  605,  620,  620,  620,  620,  620,  620,  620,
      620,  620,  620,  620,  620,  620,  620,  620,  620,  620,
      620,  620,  620,  620,  620,  620,  620,  620,  620,  620,
      620,  620,  620,  620,  620,  620,  620,  620,  620,  620,
      620,  620,  620,  620,  620,  620,  605,  605,  605,  620,
      620,  620,  620,  620,  620,  620,  620,  620,  620,  620,
      620,  620,  620,  620,  620,  620,  620,  620,  620,  620,
      620,  620,  620,  620,  620,  620,  620,  620,  620,  620,

      620,  620,  620,  620,  620,  620,  620,  605,  605,  605,
      620,  620,  620,  620,  620,  620,  620,  620,  620,  620,
      620,  620,  620,  620,  620,  620,  620,  620,  620,  620,
      620,  620,  620,  620,  620,  620,  620,  620,  620,  620,
      620,  605,  620,  620,  620,  620,  620,  620,  620,  620,
      620,  620,  620,  620,  620,  620,  620,  620,  620,  620,
      620,  620,  620,  605,  605,  620,  620,  620,  620,  620,
      620,  620,  620,  620,  605,  605,  605,  620,  620,  620,
      620,  620,  620,  620,  620,  620,  620,  620,  620,  620,
      620,  620,  620,  620,  620,  620,  620,  620,  620,  620,

      620,  620,  620,  620,  623,  620,  620,  620,  620,  620,
      620,  620,  620,  620,  620,  620,  620,  620,  620,  620,
      620,  620,  620,  620,  620,  620,  620,  623,  623,  620,
      620,  620,  620,  620,  620,  620,  620,  620,  620,  620,
      620,  620,  620,  620,  620,  620,  620,  623,  620,  620,
      620,  620,  620,  620,  620,  620,  620,  620,  620,  620,
      620,  620,  620,  620,  620,  620,  620,  605,  605,  620,
      620,  605,  605,  620,  620,  620,  620,  620,  620,  620,
      605,  620,  620,  620,  620,  620,  620,  620,  620,  620,
      620,  620,  620,  620,  620,  620,  620,  620,  620,  620,

      620,  620,  620,  620,    0,  605,  605,  605,  605,  605,
      605,  605,  605,  605,  605,  605,  605,  605,  605,  605,
      605,  605,  605
    } ;

static const flex_int16_t yy_nxt[1442] =
    {   0,
       36,   37,   38,   37,   39,   37,   36,   40,   36,   41,
       42,   36,   36,   43,   44,   36,   45,   46,   47,   48,
       48,   49,   50,   51,   52,   43,   36,   36,   53,   53,
       53,   53,   54,   36,   36,   55,   53,   53,   53,   53,
       53,   53,   53,   53,   53,   53,   53,   53,   53,   53,
       53,   53,   53,   53,   53,   53,   53,   53,   53,   56,
       57,   43,   36,   36,   36,   36,   36,   36,   36,   36,
       36,   36,   36,   36,   60,   60,  154,  157,  157,  157,
      155,  183,  183,   61,   61,   62,  159,   64,   62,   65,
      158,   76,   76,   63,   63,   66,   77,   77,  160,   63,

       63,   78,   78,   63,   63,  604,   79,   79,  242,   63,
       63,   81,   38,   81,   82,   81,  158,  243,   67,  189,
       89,  157,  157,  157,   83,   89,  195,   84,   90,  188,
       91,   85,  603,   90,  196,   91,  180,  180,  180,  182,
      182,  182,   86,  185,  185,  185,  197,   62,   62,   62,
       62,   68,   69,   70,   71,   72,   73,   74,   75,   62,
      198,   64,   62,   65,   81,   38,   81,   82,   81,   66,
      199,   87,  256,  256,   62,  221,   63,   83,   92,   93,
       84,   94,   95,   92,   85,  222,   62,  348,   63,   96,
      349,   93,   67,   94,   95,   86,  123,   38,  123,  124,

      123,   96,  200,  154,  291,   63,  103,  155,  104,  125,
      602,  103,  126,  104,   63,  292,  192,   63,  201,   63,
      193,   62,   62,   62,   62,   68,   69,   70,   71,   72,
       73,   74,   75,   62,  296,   63,  194,  105,   93,  154,
       97,   95,  105,  155,   62,   62,   63,  237,   96,   93,
      297,   97,   95,   62,   98,   63,  154,   62,   93,   96,
      155,   95,  223,  238,   63,   98,  239,  224,   96,  244,
      229,   62,  225,   63,  230,   63,   93,   62,  245,   95,
      601,  240,   62,  231,   63,  241,   96,  246,  301,  195,
       99,   62,  100,   63,  321,  321,   93,  196,   97,   95,

      189,   99,   63,  100,   62,   62,   96,   63,  302,  106,
      188,  107,   98,   63,  108,   62,  102,   63,   62,  233,
       63,  303,   63,   93,   62,   97,   95,   62,  600,   63,
      307,  599,  234,   96,  308,   63,   63,  235,  102,   98,
      109,  387,   62,  203,  204,  203,  205,  203,   99,   63,
      101,  106,  110,  107,  111,  110,  108,  111,   63,   63,
      112,  387,   62,  112,  598,  123,   38,  123,  124,  123,
      192,  327,  127,  197,  193,   99,   62,  101,  125,  328,
       62,  126,  109,  109,  344,  597,  109,  198,  596,   62,
      194,  345,  208,  209,  208,  210,  208,  199,   62,  157,

      157,  157,  180,  180,  180,  180,  180,  180,  180,  180,
      180,  260,  260,  260,  261,  261,  261,  262,  262,  262,
      475,  595,   62,   62,  211,  529,   62,  113,  114,   38,
      114,  115,  114,  113,  113,  113,  113,  113,  113,  113,
      113,  116,  113,  117,  118,  119,  119,  119,  113,  113,
      113,  113,  113,  113,  113,  117,  117,  117,  117,  113,
      113,  120,  117,  117,  117,  117,  117,  117,  117,  117,
      117,  117,  117,  117,  117,  117,  117,  117,  117,  117,
      117,  117,  117,  117,  117,  117,  113,  113,  113,  113,
      113,  113,  113,  113,  113,  113,  113,  113,  113,  113,

      113,  130,  352,  216,  216,  216,  217,  216,  131,  263,
      264,  263,  265,  263,  180,  180,  180,  594,  132,  353,
      131,  131,  131,  131,  180,  180,  180,  131,  131,  133,
      134,  135,  136,  137,  138,  131,  139,  131,  140,  141,
      142,  143,  144,  131,  145,  146,  147,  148,  149,  131,
      150,  151,  128,  266,  267,  266,  268,  266,  128,  346,
      128,  218,  593,  128,  128,  592,  347,  152,  152,  591,
      153,  153,  153,  128,  180,  180,  180,  590,  128,  128,
      153,  153,  153,  153,  589,  128,  128,  153,  153,  153,
      153,  153,  153,  153,  153,  153,  153,  153,  153,  153,

      153,  153,  153,  153,  153,  153,  153,  153,  153,  153,
      153,  200,  588,  587,  128,  128,  128,  128,  128,  128,
      128,  128,  128,  128,  128,  128,  167,  201,  586,  168,
      605,  400,  168,  269,  270,  269,  271,  269,  585,  584,
      169,  169,  272,  273,  272,  274,  272,  583,  168,  582,
      580,  400,  170,  284,  578,  168,  577,  285,  171,  172,
      415,  211,  419,  173,  576,  252,  252,  252,  575,  286,
      174,  257,  257,  257,  175,  252,  176,  177,  178,  179,
      416,  257,  419,  252,  252,  252,  252,  252,  252,  257,
      257,  257,  257,  257,  257,  258,  258,  258,  442,  442,

      442,  259,  259,  259,  574,  258,  203,  204,  203,  205,
      203,  259,  571,  258,  258,  258,  258,  258,  258,  259,
      259,  259,  259,  259,  259,  276,  209,  276,  277,  276,
      279,  280,  279,  281,  279,  216,  216,  216,  217,  216,
      322,  322,  322,  570,  567,  566,  323,  323,  323,  565,
      322,  263,  264,  263,  265,  263,  323,  564,  322,  322,
      322,  322,  322,  322,  323,  323,  323,  323,  323,  323,
      266,  267,  266,  268,  266,  563,  259,  259,  259,  269,
      270,  269,  271,  269,  562,  561,  259,  272,  273,  272,
      274,  272,  560,  218,  259,  259,  259,  259,  259,  259,

      203,  204,  203,  205,  203,  276,  209,  276,  277,  276,
      276,  209,  276,  277,  276,  279,  280,  279,  281,  279,
      368,  368,  368,  559,  556,  555,  369,  369,  369,  554,
      368,  553,  552,  439,  448,  478,  369,  551,  368,  368,
      368,  368,  368,  368,  369,  369,  369,  369,  369,  369,
      409,  409,  409,  440,  449,  479,  410,  410,  410,  550,
      409,  464,  464,  464,  464,  464,  410,  557,  409,  409,
      409,  409,  409,  409,  410,  410,  410,  410,  410,  410,
      258,  258,  258,  475,  465,  548,  549,  558,  529,  475,
      258,  476,  477,  464,  464,  464,  464,  464,  258,  258,

      258,  258,  258,  258,  558,  442,  442,  442,  568,  568,
      568,  568,  568,  579,  529,  547,  465,  572,  572,  572,
      572,  572,  546,  545,  558,  568,  568,  568,  568,  568,
      544,  569,  543,  579,  572,  572,  572,  572,  572,  542,
      573,  581,  581,  581,  581,  581,  541,  540,  569,  581,
      581,  581,  581,  581,  539,  538,  537,  573,   59,   59,
       59,   59,   59,   59,   59,   59,   59,   59,   59,   59,
       63,   63,   63,   63,   63,   63,   63,   63,   63,   63,
       63,   63,   80,   80,   80,   80,   80,   80,   80,   80,
       80,   80,   80,   80,   88,   88,   88,   88,   88,   88,

       88,   88,   88,   88,   88,   88,  122,  122,  122,  122,
      122,  122,  122,  122,  122,  122,  122,  122,  128,  536,
      535,  534,  128,  128,  533,  128,  532,  531,  530,  128,
      156,  156,  153,  153,  153,  166,  166,  166,  166,  166,
      166,  166,  166,  166,  166,  166,  166,  184,  184,  184,
      184,  184,  184,  188,  188,  188,  188,  188,  188,  188,
      188,  188,  529,  188,  188,  207,  207,  207,  207,  207,
      207,  207,  207,  207,  207,  213,  527,  526,  213,  213,
      525,  524,  213,  213,  213,  213,  214,  214,  214,  215,
      215,  215,  250,  250,  523,  250,  250,  250,  250,  250,

      250,  250,  250,  250,  251,  251,  251,  528,  528,  522,
      528,  528,  528,  528,  528,  528,  528,  528,  528,  521,
      520,  519,  518,  517,  516,  515,  514,  513,  512,  511,
      510,  509,  508,  507,  506,  505,  475,  504,  503,  502,
      501,  500,  499,  498,  497,  496,  495,  494,  493,  492,
      491,  490,  489,  488,  487,  486,  485,  484,  483,  482,
      481,  480,  474,  473,  472,  471,  470,  469,  468,  467,
      466,  463,  462,  461,  460,  459,  458,  457,  456,  455,
      454,  453,  452,  451,  450,  447,  446,  445,  444,  443,
      441,  438,  437,  436,  435,  434,  433,  432,  431,  430,

      429,  428,  427,  426,  425,  424,  423,  422,  421,  420,
      418,  417,  414,  413,  412,  411,  408,  407,  406,  405,
      404,  403,  402,  401,  399,  398,  397,  396,  395,  394,
      393,  392,  391,  390,  389,  388,  386,  385,  384,  383,
      382,  381,  380,  379,  378,  377,  376,  375,  374,  373,
      372,  371,  370,  367,  366,  365,  364,  363,  362,  361,
      360,  359,  358,  357,  356,  355,  354,  351,  350,  343,
      342,  341,  340,  339,  338,  337,  336,  335,  334,  333,
      332,  331,  330,  329,  326,  325,  324,  280,  209,  273,
      270,  267,  264,  320,  319,  318,  317,  316,  315,  314,

      313,  312,  311,  310,  309,  306,  305,  304,  300,  299,
      298,  295,  294,  293,  290,  289,  288,  287,  283,  282,
      216,  209,  278,  204,  275,  190,  189,  166,  255,  254,
      253,  249,  248,  247,  236,  232,  228,  227,  226,  220,
      219,  162,  129,  162,  129,  212,  206,  202,  191,  189,
      190,  189,  162,  129,  187,  186,  181,  165,  164,  163,
      162,  161,  129,  605,  121,   58,   35,  605,  605,  605,
      605,  605,  605,  605,  605,  605,  605,  605,  605,  605,
      605,  605,  605,  605,  605,  605,  605,  605,  605,  605,
      605,  605,  605,  605,  605,  605,  605,  605,  605,  605,

      605,  605,  605,  605,  605,  605,  605,  605,  605,  605,
      605,  605,  605,  605,  605,  605,  605,  605,  605,  605,
      605,  605,  605,  605,  605,  605,  605,  605,  605,  605,
      605,  605,  605,  605,  605,  605,  605,  605,  605,  605,
      605
    } ;

static const flex_int16_t yy_chk[1442] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    3,    4,   46,   47,   47,   47,
       46,   71,   71,    3,    4,    5,   51,    5,    5,    5,
       47,    7,    8,    7,    8,    5,    7,    8,   51,    7,

        8,    9,   10,    9,   10,  603,    9,   10,  146,    9,
       10,   11,   11,   11,   11,   11,   47,  146,    5,   89,
       13,   48,   48,   48,   11,   14,   97,   11,   13,   89,
       13,   11,  602,   14,   97,   14,   68,   68,   68,   70,
       70,   70,   11,   73,   73,   73,   98,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    6,
       98,    6,    6,    6,   12,   12,   12,   12,   12,    6,
       98,   12,  169,  169,   15,  135,   15,   12,   13,   15,
       12,   15,   15,   14,   12,  135,   16,  303,   16,   15,
      303,   16,    6,   16,   16,   12,   33,   33,   33,   33,

       33,   16,  102,   84,  226,   15,   25,   84,   25,   33,
      601,   26,   33,   26,   25,  226,   96,   16,  102,   26,
       96,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,   17,  230,   17,   96,   25,   17,  118,
       17,   17,   26,  118,   18,   15,   18,  144,   17,   18,
      230,   18,   18,   19,   17,   19,  126,   16,   19,   18,
      126,   19,  136,  144,   17,   18,  144,  136,   19,  147,
      140,   20,  136,   20,  140,   18,   20,   25,  147,   20,
      600,  145,   26,  140,   19,  145,   20,  147,  234,  267,
       17,   21,   17,   21,  256,  256,   21,  267,   21,   21,

      189,   18,   20,   18,   17,   23,   21,   23,  234,   27,
      189,   27,   21,   23,   27,   18,   23,   27,   22,  142,
       22,  234,   21,   22,   19,   22,   22,   24,  599,   24,
      238,  597,  142,   22,  238,   24,   23,  142,   24,   22,
       27,  343,   20,  105,  105,  105,  105,  105,   21,   22,
       21,   28,   29,   28,   29,   30,   28,   30,   24,   28,
       29,  343,   21,   30,  596,   34,   34,   34,   34,   34,
      264,  285,   34,  270,  264,   22,   23,   22,   34,  285,
       27,   34,   28,   29,  301,  595,   30,  270,  594,   22,
      264,  301,  109,  109,  109,  109,  109,  270,   24,  157,

      157,  157,  181,  181,  181,  182,  182,  182,  183,  183,
      183,  184,  184,  184,  185,  185,  185,  186,  186,  186,
      548,  593,   28,   29,  109,  548,   30,   31,   31,   31,
       31,   31,   31,   31,   31,   31,   31,   31,   31,   31,
       31,   31,   31,   31,   31,   31,   31,   31,   31,   31,
       31,   31,   31,   31,   31,   31,   31,   31,   31,   31,
       31,   31,   31,   31,   31,   31,   31,   31,   31,   31,
       31,   31,   31,   31,   31,   31,   31,   31,   31,   31,
       31,   31,   31,   31,   31,   31,   31,   31,   31,   31,
       31,   31,   31,   31,   31,   31,   31,   31,   31,   31,

       31,   41,  306,  132,  132,  132,  132,  132,   41,  194,
      194,  194,  194,  194,  260,  260,  260,  590,   41,  306,
       41,   41,   41,   41,  261,  261,  261,   41,   41,   41,
       41,   41,   41,   41,   41,   41,   41,   41,   41,   41,
       41,   41,   41,   41,   41,   41,   41,   41,   41,   41,
       41,   41,   45,  196,  196,  196,  196,  196,   45,  302,
       45,  132,  589,   45,   45,  588,  302,   45,   45,  587,
       45,   45,   45,   45,  262,  262,  262,  585,   45,   45,
       45,   45,   45,   45,  584,   45,   45,   45,   45,   45,
       45,   45,   45,   45,   45,   45,   45,   45,   45,   45,

       45,   45,   45,   45,   45,   45,   45,   45,   45,   45,
       45,  273,  583,  582,   45,   45,   45,   45,   45,   45,
       45,   45,   45,   45,   45,   45,   67,  273,  580,   67,
      280,  356,   67,  199,  199,  199,  199,  199,  579,  576,
       67,   67,  201,  201,  201,  201,  201,  575,   67,  574,
      571,  356,   67,  221,  567,   67,  566,  221,   67,   67,
      377,  280,  380,   67,  559,  158,  158,  158,  558,  221,
       67,  170,  170,  170,   67,  158,   67,   67,   67,   67,
      377,  170,  380,  158,  158,  158,  158,  158,  158,  170,
      170,  170,  170,  170,  170,  177,  177,  177,  408,  408,

      408,  179,  179,  179,  557,  177,  203,  203,  203,  203,
      203,  179,  555,  177,  177,  177,  177,  177,  177,  179,
      179,  179,  179,  179,  179,  208,  208,  208,  208,  208,
      211,  211,  211,  211,  211,  216,  216,  216,  216,  216,
      257,  257,  257,  554,  552,  551,  258,  258,  258,  550,
      257,  263,  263,  263,  263,  263,  258,  549,  257,  257,
      257,  257,  257,  257,  258,  258,  258,  258,  258,  258,
      266,  266,  266,  266,  266,  547,  259,  259,  259,  269,
      269,  269,  269,  269,  546,  545,  259,  272,  272,  272,
      272,  272,  543,  216,  259,  259,  259,  259,  259,  259,

      275,  275,  275,  275,  275,  276,  276,  276,  276,  276,
      278,  278,  278,  278,  278,  279,  279,  279,  279,  279,
      322,  322,  322,  542,  539,  538,  323,  323,  323,  536,
      322,  535,  534,  405,  417,  443,  323,  533,  322,  322,
      322,  322,  322,  322,  323,  323,  323,  323,  323,  323,
      368,  368,  368,  405,  417,  443,  369,  369,  369,  531,
      368,  432,  432,  432,  432,  432,  369,  540,  368,  368,
      368,  368,  368,  368,  369,  369,  369,  369,  369,  369,
      409,  409,  409,  529,  432,  529,  530,  540,  529,  442,
      409,  442,  442,  464,  464,  464,  464,  464,  409,  409,

      409,  409,  409,  409,  541,  442,  442,  442,  553,  553,
      553,  553,  553,  570,  528,  527,  464,  556,  556,  556,
      556,  556,  526,  525,  541,  568,  568,  568,  568,  568,
      524,  553,  523,  570,  572,  572,  572,  572,  572,  522,
      556,  573,  573,  573,  573,  573,  521,  520,  568,  581,
      581,  581,  581,  581,  519,  516,  515,  572,  606,  606,
      606,  606,  606,  606,  606,  606,  606,  606,  606,  606,
      607,  607,  607,  607,  607,  607,  607,  607,  607,  607,
      607,  607,  608,  608,  608,  608,  608,  608,  608,  608,
      608,  608,  608,  608,  609,  609,  609,  609,  609,  609,

      609,  609,  609,  609,  609,  609,  610,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  611,  514,
      513,  510,  611,  611,  509,  611,  508,  507,  506,  611,
      612,  612,  613,  613,  613,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  615,  615,  615,
      615,  615,  615,  616,  616,  616,  616,  616,  616,  616,
      616,  616,  505,  616,  616,  617,  617,  617,  617,  617,
      617,  617,  617,  617,  617,  618,  504,  503,  618,  618,
      501,  500,  618,  618,  618,  618,  619,  619,  619,  620,
      620,  620,  621,  621,  499,  621,  621,  621,  621,  621,

      621,  621,  621,  621,  622,  622,  622,  623,  623,  498,
      623,  623,  623,  623,  623,  623,  623,  623,  623,  495,
      493,  492,  491,  490,  488,  487,  486,  485,  484,  483,
      482,  481,  480,  479,  478,  477,  476,  473,  472,  471,
      469,  467,  466,  463,  462,  461,  460,  459,  458,  457,
      456,  455,  454,  453,  452,  451,  450,  449,  448,  447,
      446,  445,  441,  440,  439,  438,  437,  436,  435,  434,
      433,  431,  430,  429,  428,  427,  426,  425,  424,  423,
      422,  421,  420,  419,  418,  416,  415,  414,  413,  412,
      407,  403,  401,  400,  399,  398,  397,  395,  393,  392,

      391,  390,  389,  388,  387,  385,  384,  383,  382,  381,
      379,  378,  374,  373,  372,  370,  367,  365,  364,  362,
      360,  359,  358,  357,  355,  354,  353,  352,  351,  350,
      349,  348,  347,  346,  345,  344,  342,  341,  340,  338,
      337,  336,  335,  334,  333,  332,  331,  330,  329,  328,
      327,  326,  324,  320,  319,  318,  317,  316,  315,  314,
      313,  312,  311,  310,  309,  308,  307,  305,  304,  300,
      299,  298,  297,  296,  295,  294,  293,  292,  291,  290,
      289,  288,  287,  286,  284,  283,  282,  281,  277,  274,
      271,  268,  265,  255,  249,  248,  247,  246,  245,  244,

      243,  242,  241,  240,  239,  237,  236,  235,  233,  232,
      231,  229,  228,  227,  225,  224,  223,  222,  220,  219,
      217,  210,  209,  205,  204,  190,  188,  167,  162,  161,
      159,  150,  149,  148,  143,  141,  139,  138,  137,  134,
      133,  127,  124,  121,  115,  111,  107,  104,   94,   92,
       90,   88,   87,   82,   79,   74,   69,   65,   61,   60,
       58,   55,   39,   35,   32,    2,  605,  605,  605,  605,
      605,  605,  605,  605,  605,  605,  605,  605,  605,  605,
      605,  605,  605,  605,  605,  605,  605,  605,  605,  605,
      605,  605,  605,  605,  605,  605,  605,  605,  605,  605,

      605,  605,  605,  605,  605,  605,  605,  605,  605,  605,
      605,  605,  605,  605,  605,  605,  605,  605,  605,  605,
      605,  605,  605,  605,  605,  605,  605,  605,  605,  605,
      605,  605,  605,  605,  605,  605,  605,  605,  605,  605,
      605
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 1;

static const flex_int16_t yy_rule_linenum[131] =
    {   0,
      214,  217,  218,  219,  225,  243,  244,  245,  246,  247,
      248,  249,  250,  251,  252,  253,  254,  255,  256,  257,
      258,  259,  260,  261,  262,  263,  264,  265,  266,  267,
      268,  269,  270,  271,  272,  273,  274,  275,  276,  277,
      278,  279,  280,  281,  282,  283,  287,  291,  295,  298,
      299,  300,  301,  302,  303,  304,  305,  306,  308,  313,
      314,  315,  316,  318,  325,  326,  330,  336,  339,  340,
      343,  346,  354,  361,  362,  363,  369,  376,  383,  404,
      419,  434,  440,  459,  473,  492,  508,  525,  526,  537,
      548,  549,  561,  571,  576,  586,  598,  622,  634,  648,

      649,  660,  664,  668,  669,  670,  671,  672,  673,  674,
      677,  679,  683,  695,  711,  716,  717,  723,  724,  735,
      741,  747,  753,  769,  770,  774,  781,  797,  817,  856
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "/Users/akim/src/gnu/bison/src/scan-gram.l"
/* Bison Grammar Scanner                             -*- C -*-

   Copyright (C) 2002-2015, 2018-2021 Free Software Foundation, Inc.

   This file is part of Bison, the GNU Compiler Compiler.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
#define YY_NO_INPUT 1
#line 24 "/Users/akim/src/gnu/bison/src/scan-gram.l"
#include <c-ctype.h>
#include <errno.h>
#include <mbswidth.h>
#include <quote.h>
#include <quotearg.h>

#include "src/complain.h"
#include "src/files.h"
#include "src/getargs.h"
#include "src/gram.h"
#include "src/reader.h"
#include "src/scan-gram.h"
#include "src/uniqstr.h"

#define FLEX_PREFIX(Id) gram_ ## Id
#include "src/flex-scanner.h"

/* Work around a bug in flex 2.5.31.  See Debian bug 333231
   <https://bugs.debian.org/333231>.  */
#undef gram_wrap
#define gram_wrap() 1

#define YY_DECL GRAM_LEX_DECL

/* Location of scanner cursor.  */
static boundary scanner_cursor;

#define YY_USER_ACTION  location_compute (loc, &scanner_cursor, yytext, yyleng);

/* Report that yytext is an extension, and evaluate to its token kind.  */
#define BISON_DIRECTIVE(Directive)                              \
  (bison_directive (loc, yytext), PERCENT_ ## Directive)

#define RETURN_PERCENT_PARAM(Value)             \
  RETURN_VALUE(PERCENT_PARAM, param_ ## Value)

#define RETURN_PERCENT_FLAG(Value)                      \
  RETURN_VALUE(PERCENT_FLAG, uniqstr_new (Value))

#define RETURN_VALUE(Token, Value)              \
  do {                                          \
    val->Token = Value;                         \
    return Token;                               \
  } while (0)

#define ROLLBACK_CURRENT_TOKEN                                  \
  do {                                                          \
    scanner_cursor.column -= mbsnwidth (yytext, yyleng, 0);     \
    scanner_cursor.byte -= yyleng;                              \
    yyless (0);                                                 \
  } while (0)

#define DEPRECATED_DIRECTIVE(Msg)                               \
  do {                                                          \
    deprecated_directive (loc, yytext, Msg);                    \
    scanner_cursor.column -= mbsnwidth (Msg, strlen (Msg), 0);  \
    scanner_cursor.byte -= strlen (Msg);                        \
    for (size_t i = strlen (Msg); i != 0; --i)                  \
      unput (Msg[i - 1]);                                       \
  } while (0)


#define STRING_GROW_ESCAPE(Char)                                \
  do {                                                          \
    verify (UCHAR_MAX < ULONG_MAX);                             \
    long c = Char;                                              \
    bool valid = 0 < c && c <= UCHAR_MAX;                       \
    if (!valid)                                                 \
      complain (loc, complaint,                                 \
                _("invalid number after \\-escape: %s"),        \
                yytext + 1);                                    \
    if (YY_START == SC_ESCAPED_CHARACTER)                       \
      STRING_1GROW (valid ? c : '?');                           \
    else                                                        \
      STRING_GROW ();                                           \
  } while (0)


/* The current file name.  Might change with #line.  */
static uniqstr current_file = NULL;

/* A string representing the most recently saved token.  */
static char *last_string = NULL;

/* Bracketed identifier. */
static uniqstr bracketed_id_str = NULL;
static location bracketed_id_loc;
static boundary bracketed_id_start;
static int bracketed_id_context_state = 0;

void
gram_scanner_last_string_free (void)
{
  STRING_FREE ();
}

static void handle_syncline (char *, location);
static int scan_integer (char const *p, int base, location loc);
static int convert_ucn_to_byte (char const *hex_text);
static void unexpected_eof (boundary, char const *);
static void unexpected_newline (boundary, char const *);

#line 1445 "src/scan-gram.c"
#line 128 "/Users/akim/src/gnu/bison/src/scan-gram.l"
 /* A C-like comment in directives/rules. */

 /* Characters and strings in directives/rules. */

 /* A identifier was just read in directives/rules.  Special state
    to capture the sequence 'identifier :'. */

 /* POSIX says that a tag must be both an id and a C union member, but
    historically almost any character is allowed in a tag.  We
    disallow NUL, as this simplifies our implementation.  We match
    angle brackets in nested pairs: several languages use them for
    generics/template types.  */

 /* Four types of user code:
    - prologue (code between '%{' '%}' in the first section, before %%);
    - actions, printers, union, etc, (between braced in the middle section);
    - epilogue (everything after the second %%).
    - predicate (code between '%?{' and '{' in middle section); */

 /* C and C++ comments in code. */

 /* Strings and characters in code. */

 /* Bracketed identifiers support. */

 /* UTF-8 Encoded Unicode Code Point, from Flex's documentation. */
/* Zero or more instances of backslash-newline.  Following GCC, allow
   white space between the backslash and the newline.  */
/* An equal sign, with optional leading whitespaces. This is used in some
   deprecated constructs. */
#line 1477 "src/scan-gram.c"

#define INITIAL 0
#define SC_YACC_COMMENT 1
#define SC_ESCAPED_CHARACTER 2
#define SC_ESCAPED_STRING 3
#define SC_ESCAPED_TSTRING 4
#define SC_AFTER_IDENTIFIER 5
#define SC_TAG 6
#define SC_PROLOGUE 7
#define SC_BRACED_CODE 8
#define SC_EPILOGUE 9
#define SC_PREDICATE 10
#define SC_COMMENT 11
#define SC_LINE_COMMENT 12
#define SC_STRING 13
#define SC_CHARACTER 14
#define SC_BRACKETED_ID 15
#define SC_RETURN_BRACKETED_ID 16

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
/* %if-c-only */
#include <unistd.h>
/* %endif */
/* %if-c++-only */
/* %endif */
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* %if-c-only Reentrant structure and macros (non-C++). */
/* %if-reentrant */
/* %if-c-only */

static int yy_init_globals ( void );

/* %endif */
/* %if-reentrant */
/* %endif */
/* %endif End reentrant structures and macros. */

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* %if-bison-bridge */
/* %endif */

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

/* %not-for-header */
#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  );
    
#endif
/* %ok-for-header */

/* %endif */

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
/* %if-c-only Standard (non-C++) definition */
/* %not-for-header */
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif
/* %ok-for-header */

/* %endif */
#endif

/* %if-c-only */

/* %endif */

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* %if-c-only Standard (non-C++) definition */
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
/* %endif */
/* %if-c++-only C++ definition */
/* %endif */
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
/* %% [5.0] fread()/read() definition of YY_INPUT goes here unless we're doing C++ \ */\
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\
/* %if-c++-only C++ definition \ */\
/* %endif */

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
/* %if-c-only */
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
/* %endif */
/* %if-c++-only */
/* %endif */
#endif

/* %if-tables-serialization structures and prototypes */
/* %not-for-header */
/* %ok-for-header */

/* %not-for-header */
/* %tables-yydmap generated elements */
/* %endif */
/* end tables serialization structures and prototypes */

/* %ok-for-header */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1
/* %if-c-only Standard (non-C++) definition */

extern int yylex (void);

#define YY_DECL int yylex (void)
/* %endif */
/* %if-c++-only C++ definition */
/* %endif */
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

/* %% [6.0] YY_RULE_SETUP definition goes here */
#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/* %not-for-header */
/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
/* %if-c-only */
			yyin = stdin;
/* %endif */
/* %if-c++-only */
/* %endif */

		if ( ! yyout )
/* %if-c-only */
			yyout = stdout;
/* %endif */
/* %if-c++-only */
/* %endif */

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
/* %% [7.0] user's declarations go here */
#line 175 "/Users/akim/src/gnu/bison/src/scan-gram.l"


  /* Nesting level.  Either for nested braces, or nested angle brackets
     (but not mixed).  */
  int nesting PACIFY_CC (= 0);

  /* Parent context state, when applicable.  */
  int context_state PACIFY_CC (= 0);

  /* Location of most recent identifier, when applicable.  */
  location id_loc PACIFY_CC (= empty_loc);

  /* Where containing code started, when applicable.  Its initial
     value is relevant only when yylex is invoked in the SC_EPILOGUE
     start condition.  */
  boundary code_start = scanner_cursor;

  /* Where containing comment or string or character literal started,
     when applicable.  */
  boundary token_start PACIFY_CC (= scanner_cursor);

  /* We cannot trust YY_USER_INIT, whose semantics changes over time
     (it moved in Flex 2.5.38).  */
  static bool first = true;
  if (first)
    {
      scanner_cursor = loc->start;
      first = false;
    }



  /*-----------------------.
  | Scanning white space.  |
  `-----------------------*/

#line 1813 "src/scan-gram.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
/* %% [8.0] yymore()-related code goes here */
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

/* %% [9.0] code to set up and find next match goes here */
		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 606 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 605 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
/* %% [10.0] code to find the action number goes here */
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

/* %% [11.0] code for yylineno update goes here */

do_action:	/* This label is used only to access EOF actions. */

/* %% [12.0] debug code goes here */
		if ( yy_flex_debug )
			{
			if ( yy_act == 0 )
				fprintf( stderr, "--scanner backing up\n" );
			else if ( yy_act < 131 )
				fprintf( stderr, "--accepting rule at line %ld (\"%s\")\n",
				         (long)yy_rule_linenum[yy_act], yytext );
			else if ( yy_act == 131 )
				fprintf( stderr, "--accepting default rule (\"%s\")\n",
				         yytext );
			else if ( yy_act == 132 )
				fprintf( stderr, "--(end of buffer or a NUL)\n" );
			else
				fprintf( stderr, "--EOF (start condition %d)\n", YY_START );
			}

		switch ( yy_act )
	{ /* beginning of action switch */
/* %% [13.0] actions go here */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

/* Comments and white space.  */
case 1:
YY_RULE_SETUP
#line 214 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
     complain (loc, Wother, _("stray ',' treated as white space"));
  }
	YY_BREAK
case 2:
/* rule 2 can match eol */
#line 218 "/Users/akim/src/gnu/bison/src/scan-gram.l"
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 218 "/Users/akim/src/gnu/bison/src/scan-gram.l"
continue;
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 219 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    token_start = loc->start;
    context_state = YY_START;
    BEGIN SC_YACC_COMMENT;
  }
	YY_BREAK
case 5:
/* rule 5 can match eol */
YY_RULE_SETUP
#line 225 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    handle_syncline (yytext + sizeof "#line " - 1, *loc);
  }
	YY_BREAK

/*----------------------------.
  | Scanning Bison directives.  |
  `----------------------------*/
/* For directives that are also command line options, the regex must be
        "%..."
     after "[-_]"s are removed, and the directive must match the --long
     option name, with a single string argument.  Otherwise, add exceptions
     to ../build-aux/cross-options.pl.  */


case 6:
YY_RULE_SETUP
#line 243 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (NONASSOC);
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 244 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (CODE);
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 245 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_PERCENT_FLAG ("parse.trace");
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 246 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (DEFAULT_PREC);
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 247 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (DEFINE);
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 248 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (DEFINES);
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 249 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (DESTRUCTOR);
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 250 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (DPREC);
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 251 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (EMPTY);
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 252 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (EXPECT);
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 253 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (EXPECT_RR);
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 254 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_VALUE (PERCENT_FILE_PREFIX, uniqstr_new (yytext));
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 255 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (INITIAL_ACTION);
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 256 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (GLR_PARSER);
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 257 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (LANGUAGE);
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 258 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return PERCENT_LEFT;
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 259 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_PERCENT_PARAM (lex);
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 260 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_PERCENT_FLAG ("locations");
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 261 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (MERGE);
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 262 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (NO_DEFAULT_PREC);
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 263 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (NO_LINES);
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 264 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return PERCENT_NONASSOC;
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 265 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (NONDETERMINISTIC_PARSER);
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 266 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (NTERM);
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 267 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (OUTPUT);
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 268 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_PERCENT_PARAM (both);
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 269 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_PERCENT_PARAM (parse);
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 270 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return PERCENT_PREC;
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 271 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (PRECEDENCE);
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 272 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (PRINTER);
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 273 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (REQUIRE);
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 274 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return PERCENT_RIGHT;
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 275 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (SKELETON);
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 276 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return PERCENT_START;
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 277 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (TOKEN);
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 278 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return PERCENT_TOKEN;
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 279 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (TOKEN_TABLE);
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 280 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return PERCENT_TYPE;
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 281 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return PERCENT_UNION;
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 282 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (VERBOSE);
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 283 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return PERCENT_YACC;
	YY_BREAK
/* Deprecated since Bison 2.3b (2008-05-27), but the warning is
     issued only since Bison 3.4. */
case 47:
YY_RULE_SETUP
#line 287 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_VALUE (PERCENT_PURE_PARSER, uniqstr_new (yytext));
	YY_BREAK
/* Deprecated since Bison 3.0 (2013-07-25), but the warning is
     issued only since Bison 3.3. */
case 48:
YY_RULE_SETUP
#line 291 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_VALUE (PERCENT_ERROR_VERBOSE, uniqstr_new (yytext));
	YY_BREAK
/* Deprecated since Bison 2.6 (2012-07-19), but the warning is
     issued only since Bison 3.3. */
case 49:
/* rule 49 can match eol */
YY_RULE_SETUP
#line 295 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_VALUE (PERCENT_NAME_PREFIX, uniqstr_new (yytext));
	YY_BREAK
/* Deprecated since Bison 2.7.90, 2012. */
case 50:
YY_RULE_SETUP
#line 298 "/Users/akim/src/gnu/bison/src/scan-gram.l"
DEPRECATED_DIRECTIVE ("%default-prec");
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 299 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_VALUE (PERCENT_ERROR_VERBOSE, uniqstr_new (yytext));
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 300 "/Users/akim/src/gnu/bison/src/scan-gram.l"
DEPRECATED_DIRECTIVE ("%expect-rr");
	YY_BREAK
case 53:
/* rule 53 can match eol */
YY_RULE_SETUP
#line 301 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_VALUE (PERCENT_FILE_PREFIX, uniqstr_new (yytext));
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 302 "/Users/akim/src/gnu/bison/src/scan-gram.l"
DEPRECATED_DIRECTIVE ("%output \"y.tab.c\"");
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 303 "/Users/akim/src/gnu/bison/src/scan-gram.l"
DEPRECATED_DIRECTIVE ("%no-default-prec");
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 304 "/Users/akim/src/gnu/bison/src/scan-gram.l"
DEPRECATED_DIRECTIVE ("%no-lines");
	YY_BREAK
case 57:
/* rule 57 can match eol */
YY_RULE_SETUP
#line 305 "/Users/akim/src/gnu/bison/src/scan-gram.l"
DEPRECATED_DIRECTIVE ("%output");
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 306 "/Users/akim/src/gnu/bison/src/scan-gram.l"
DEPRECATED_DIRECTIVE ("%token-table");
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 308 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    complain (loc, complaint, _("invalid directive: %s"), quote (yytext));
    return GRAM_error;
  }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 313 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return COLON;
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 314 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return EQUAL;
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 315 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return PIPE;
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 316 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return SEMICOLON;
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 318 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    val->ID = uniqstr_new (yytext);
    id_loc = *loc;
    bracketed_id_str = NULL;
    BEGIN SC_AFTER_IDENTIFIER;
  }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 325 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_VALUE (INT_LITERAL, scan_integer (yytext, 10, *loc));
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 326 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_VALUE (INT_LITERAL, scan_integer (yytext, 16, *loc));
	YY_BREAK
/* Identifiers may not start with a digit.  Yet, don't silently
     accept "1FOO" as "1 FOO".  */
case 67:
YY_RULE_SETUP
#line 330 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    complain (loc, complaint, _("invalid identifier: %s"), quote (yytext));
    return GRAM_error;
  }
	YY_BREAK
/* Characters.  */
case 68:
YY_RULE_SETUP
#line 336 "/Users/akim/src/gnu/bison/src/scan-gram.l"
token_start = loc->start; BEGIN SC_ESCAPED_CHARACTER;
	YY_BREAK
/* Strings. */
case 69:
YY_RULE_SETUP
#line 339 "/Users/akim/src/gnu/bison/src/scan-gram.l"
token_start = loc->start; STRING_1GROW ('"'); BEGIN SC_ESCAPED_STRING;
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 340 "/Users/akim/src/gnu/bison/src/scan-gram.l"
token_start = loc->start; STRING_1GROW ('"'); BEGIN SC_ESCAPED_TSTRING;
	YY_BREAK
/* Prologue. */
case 71:
YY_RULE_SETUP
#line 343 "/Users/akim/src/gnu/bison/src/scan-gram.l"
code_start = loc->start; BEGIN SC_PROLOGUE;
	YY_BREAK
/* Code in between braces.  */
case 72:
YY_RULE_SETUP
#line 346 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_GROW ();
    nesting = 0;
    code_start = loc->start;
    BEGIN SC_BRACED_CODE;
  }
	YY_BREAK
/* Semantic predicate. */
case 73:
/* rule 73 can match eol */
YY_RULE_SETUP
#line 354 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    nesting = 0;
    code_start = loc->start;
    BEGIN SC_PREDICATE;
  }
	YY_BREAK
/* A type. */
case 74:
YY_RULE_SETUP
#line 361 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return TAG_ANY;
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 362 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return TAG_NONE;
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 363 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    nesting = 0;
    token_start = loc->start;
    BEGIN SC_TAG;
  }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 369 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    static int percent_percent_count;
    if (++percent_percent_count == 2)
      BEGIN SC_EPILOGUE;
    return PERCENT_PERCENT;
  }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 376 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    bracketed_id_str = NULL;
    bracketed_id_start = loc->start;
    bracketed_id_context_state = YY_START;
    BEGIN SC_BRACKETED_ID;
  }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 383 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    complain (loc, complaint, "%s: %s",
              ngettext ("invalid character", "invalid characters", yyleng),
              quote_mem (yytext, yyleng));
    return GRAM_error;
  }
	YY_BREAK
case YY_STATE_EOF(INITIAL):
#line 390 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    loc->start = loc->end = scanner_cursor;
    yyterminate ();
  }
	YY_BREAK

/*--------------------------------------------------------------.
  | Supporting \0 complexifies our implementation for no expected |
  | added value.                                                  |
  `--------------------------------------------------------------*/


case 80:
YY_RULE_SETUP
#line 404 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    complain (loc, complaint, _("invalid null character"));
    STRING_FINISH ();
    STRING_FREE ();
    return GRAM_error;
  }
	YY_BREAK

/*-----------------------------------------------------------------.
  | Scanning after an identifier, checking whether a colon is next.  |
  `-----------------------------------------------------------------*/


case 81:
YY_RULE_SETUP
#line 419 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    if (bracketed_id_str)
      {
        ROLLBACK_CURRENT_TOKEN;
        BEGIN SC_RETURN_BRACKETED_ID;
        *loc = id_loc;
        return ID;
      }
    else
      {
        bracketed_id_start = loc->start;
        bracketed_id_context_state = YY_START;
        BEGIN SC_BRACKETED_ID;
      }
  }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 434 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    ROLLBACK_CURRENT_TOKEN;
    BEGIN (bracketed_id_str ? SC_RETURN_BRACKETED_ID : INITIAL);
    *loc = id_loc;
    return ID_COLON;
  }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 440 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    ROLLBACK_CURRENT_TOKEN;
    BEGIN (bracketed_id_str ? SC_RETURN_BRACKETED_ID : INITIAL);
    *loc = id_loc;
    return ID;
  }
	YY_BREAK
case YY_STATE_EOF(SC_AFTER_IDENTIFIER):
#line 446 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    BEGIN (bracketed_id_str ? SC_RETURN_BRACKETED_ID : INITIAL);
    *loc = id_loc;
    return ID;
  }
	YY_BREAK

/*--------------------------------.
  | Scanning bracketed identifiers. |
  `--------------------------------*/


case 84:
YY_RULE_SETUP
#line 459 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    if (bracketed_id_str)
      {
        complain (loc, complaint,
                  _("unexpected identifier in bracketed name: %s"),
                  quote (yytext));
        return GRAM_error;
      }
    else
      {
        bracketed_id_str = uniqstr_new (yytext);
        bracketed_id_loc = *loc;
      }
  }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 473 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    BEGIN bracketed_id_context_state;
    if (bracketed_id_str)
      {
        if (INITIAL == bracketed_id_context_state)
          {
            val->BRACKETED_ID = bracketed_id_str;
            bracketed_id_str = 0;
            *loc = bracketed_id_loc;
            return BRACKETED_ID;
          }
      }
    else
      {
        complain (loc, complaint, _("an identifier expected"));
        return GRAM_error;
      }
  }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 492 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    complain (loc, complaint, "%s: %s",
              ngettext ("invalid character in bracketed name",
                        "invalid characters in bracketed name", yyleng),
              quote_mem (yytext, yyleng));
    return GRAM_error;
  }
	YY_BREAK
case YY_STATE_EOF(SC_BRACKETED_ID):
#line 500 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    BEGIN bracketed_id_context_state;
    unexpected_eof (bracketed_id_start, "]");
  }
	YY_BREAK



case 87:
YY_RULE_SETUP
#line 508 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    ROLLBACK_CURRENT_TOKEN;
    val->BRACKETED_ID = bracketed_id_str;
    bracketed_id_str = 0;
    *loc = bracketed_id_loc;
    BEGIN INITIAL;
    return BRACKETED_ID;
  }
	YY_BREAK

/*---------------------------------------------------------------.
  | Scanning a Yacc comment.  The initial '/ *' is already eaten.  |
  `---------------------------------------------------------------*/


case 88:
YY_RULE_SETUP
#line 525 "/Users/akim/src/gnu/bison/src/scan-gram.l"
BEGIN context_state;
	YY_BREAK
case 89:
/* rule 89 can match eol */
YY_RULE_SETUP
#line 526 "/Users/akim/src/gnu/bison/src/scan-gram.l"
continue;
	YY_BREAK
case YY_STATE_EOF(SC_YACC_COMMENT):
#line 527 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_eof (token_start, "*/"); BEGIN context_state;
	YY_BREAK

/*------------------------------------------------------------.
  | Scanning a C comment.  The initial '/ *' is already eaten.  |
  `------------------------------------------------------------*/


case 90:
/* rule 90 can match eol */
YY_RULE_SETUP
#line 537 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW (); BEGIN context_state;
	YY_BREAK
case YY_STATE_EOF(SC_COMMENT):
#line 538 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_eof (token_start, "*/"); BEGIN context_state;
	YY_BREAK

/*--------------------------------------------------------------.
  | Scanning a line comment.  The initial '//' is already eaten.  |
  `--------------------------------------------------------------*/


case 91:
/* rule 91 can match eol */
YY_RULE_SETUP
#line 548 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW (); BEGIN context_state;
	YY_BREAK
case 92:
/* rule 92 can match eol */
YY_RULE_SETUP
#line 549 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW ();
	YY_BREAK
case YY_STATE_EOF(SC_LINE_COMMENT):
#line 550 "/Users/akim/src/gnu/bison/src/scan-gram.l"
BEGIN context_state;
	YY_BREAK

/*------------------------------------------------.
  | Scanning a Bison string, including its escapes. |
  | The initial quote is already eaten.             |
  `------------------------------------------------*/


case 93:
YY_RULE_SETUP
#line 561 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_1GROW ('"');
    STRING_FINISH ();
    BEGIN INITIAL;
    loc->start = token_start;
    complain (loc, Wyacc,
              _("POSIX Yacc does not support string literals"));
    RETURN_VALUE (STRING, last_string);
  }
	YY_BREAK
case YY_STATE_EOF(SC_ESCAPED_STRING):
#line 570 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_eof (token_start, "\"");
	YY_BREAK
case 94:
/* rule 94 can match eol */
YY_RULE_SETUP
#line 571 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_newline (token_start, "\"");
	YY_BREAK



case 95:
YY_RULE_SETUP
#line 576 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_1GROW ('"');
    STRING_FINISH ();
    BEGIN INITIAL;
    loc->start = token_start;
    complain (loc, Wyacc,
              _("POSIX Yacc does not support string literals"));
    RETURN_VALUE (TSTRING, last_string);
  }
	YY_BREAK
case YY_STATE_EOF(SC_ESCAPED_TSTRING):
#line 585 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_eof (token_start, "\")");
	YY_BREAK
case 96:
/* rule 96 can match eol */
YY_RULE_SETUP
#line 586 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_newline (token_start, "\")");
	YY_BREAK

/*----------------------------------------------------------.
  | Scanning a Bison character literal, decoding its escapes. |
  | The initial quote is already eaten.                       |
  `----------------------------------------------------------*/


case 97:
YY_RULE_SETUP
#line 598 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_FINISH ();
    BEGIN INITIAL;
    loc->start = token_start;

    if (last_string[0] == '\0')
      {
        complain (loc, complaint, _("empty character literal"));
        STRING_FREE ();
        return GRAM_error;
      }
    else if (last_string[1] != '\0')
      {
        complain (loc, complaint, _("extra characters in character literal"));
        STRING_FREE ();
        return GRAM_error;
      }
    else
      {
        val->CHAR_LITERAL = last_string[0];
        STRING_FREE ();
        return CHAR_LITERAL;
      }
  }
	YY_BREAK
case 98:
/* rule 98 can match eol */
YY_RULE_SETUP
#line 622 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_newline (token_start, "'");
	YY_BREAK
case YY_STATE_EOF(SC_ESCAPED_CHARACTER):
#line 623 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_eof (token_start, "'");
	YY_BREAK

/*--------------------------------------------------------------.
  | Scanning a tag.  The initial angle bracket is already eaten.  |
  `--------------------------------------------------------------*/


case 99:
YY_RULE_SETUP
#line 634 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    --nesting;
    if (nesting < 0)
      {
        STRING_FINISH ();
        loc->start = token_start;
        val->TAG = uniqstr_new (last_string);
        STRING_FREE ();
        BEGIN INITIAL;
        return TAG;
      }
    STRING_GROW ();
  }
	YY_BREAK
case 100:
/* rule 100 can match eol */
YY_RULE_SETUP
#line 648 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW ();
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 649 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW (); nesting += yyleng;
	YY_BREAK
case YY_STATE_EOF(SC_TAG):
#line 651 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_eof (token_start, ">");
	YY_BREAK

/*----------------------------.
  | Decode escaped characters.  |
  `----------------------------*/


case 102:
YY_RULE_SETUP
#line 660 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_GROW_ESCAPE (strtol (yytext + 1, NULL, 8));
  }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 664 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_GROW_ESCAPE (strtol (yytext + 2, NULL, 16));
  }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 668 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW_ESCAPE ('\a');
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 669 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW_ESCAPE ('\b');
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 670 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW_ESCAPE ('\f');
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 671 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW_ESCAPE ('\n');
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 672 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW_ESCAPE ('\r');
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 673 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW_ESCAPE ('\t');
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 674 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW_ESCAPE ('\v');
	YY_BREAK
/* \\[\"\'?\\] would be shorter, but it confuses xgettext.  */
case 111:
YY_RULE_SETUP
#line 677 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW_ESCAPE (yytext[1]);
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 679 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_GROW_ESCAPE (convert_ucn_to_byte (yytext));
  }
	YY_BREAK
case 113:
/* rule 113 can match eol */
YY_RULE_SETUP
#line 683 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    char const *p = yytext + 1;
    /* Quote only if escaping won't make the character visible.  */
    if (c_isspace ((unsigned char) *p) && c_isprint ((unsigned char) *p))
      p = quote (p);
    else
      p = quotearg_style_mem (escape_quoting_style, p, 1);
    complain (loc, complaint, _("invalid character after \\-escape: %s"),
              p);
    STRING_1GROW ('?');
  }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 695 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    // None of the other rules matched: the last character of this
    // file is "\".  But Flex does not support "\\<<EOF>>".
    unexpected_eof (token_start,
                    YY_START == SC_ESCAPED_CHARACTER ? "?'"
                    : YY_START == SC_ESCAPED_STRING ? "?\""
                    : "?\")");
  }
	YY_BREAK

/*--------------------------------------------.
  | Scanning user-code characters and strings.  |
  `--------------------------------------------*/


case 115:
/* rule 115 can match eol */
YY_RULE_SETUP
#line 711 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW ();
	YY_BREAK



case 116:
YY_RULE_SETUP
#line 716 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW (); BEGIN context_state;
	YY_BREAK
case 117:
/* rule 117 can match eol */
YY_RULE_SETUP
#line 717 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_newline (token_start, "'");
	YY_BREAK
case YY_STATE_EOF(SC_CHARACTER):
#line 718 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_eof (token_start, "'");
	YY_BREAK



case 118:
YY_RULE_SETUP
#line 723 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW (); BEGIN context_state;
	YY_BREAK
case 119:
/* rule 119 can match eol */
YY_RULE_SETUP
#line 724 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_newline (token_start, "\"");
	YY_BREAK
case YY_STATE_EOF(SC_STRING):
#line 725 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_eof (token_start, "\"");
	YY_BREAK

/*---------------------------------------------------.
  | Strings, comments etc. can be found in user code.  |
  `---------------------------------------------------*/


case 120:
YY_RULE_SETUP
#line 735 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_GROW ();
    context_state = YY_START;
    token_start = loc->start;
    BEGIN SC_CHARACTER;
  }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 741 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_GROW ();
    context_state = YY_START;
    token_start = loc->start;
    BEGIN SC_STRING;
  }
	YY_BREAK
case 122:
/* rule 122 can match eol */
YY_RULE_SETUP
#line 747 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_GROW ();
    context_state = YY_START;
    token_start = loc->start;
    BEGIN SC_COMMENT;
  }
	YY_BREAK
case 123:
/* rule 123 can match eol */
YY_RULE_SETUP
#line 753 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_GROW ();
    context_state = YY_START;
    BEGIN SC_LINE_COMMENT;
  }
	YY_BREAK

/*-----------------------------------------------------------.
  | Scanning some code in braces (actions, predicates). The    |
  | initial "{" is already eaten.                              |
  `-----------------------------------------------------------*/


case 124:
/* rule 124 can match eol */
YY_RULE_SETUP
#line 769 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW (); nesting++;
	YY_BREAK
case 125:
/* rule 125 can match eol */
YY_RULE_SETUP
#line 770 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW (); nesting--;
	YY_BREAK
/* Tokenize '<<%' correctly (as '<<' '%') rather than incorrectly
     (as '<' '<%').  */
case 126:
/* rule 126 can match eol */
YY_RULE_SETUP
#line 774 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW ();
	YY_BREAK
case YY_STATE_EOF(SC_BRACED_CODE):
case YY_STATE_EOF(SC_PREDICATE):
#line 776 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_eof (code_start, "}");
	YY_BREAK



case 127:
YY_RULE_SETUP
#line 781 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_1GROW ('}');

    --nesting;
    if (nesting < 0)
      {
        STRING_FINISH ();
        loc->start = code_start;
        BEGIN INITIAL;
        RETURN_VALUE (BRACED_CODE, last_string);
      }
  }
	YY_BREAK



case 128:
YY_RULE_SETUP
#line 797 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    --nesting;
    if (nesting < 0)
      {
        STRING_FINISH ();
        loc->start = code_start;
        BEGIN INITIAL;
        RETURN_VALUE (BRACED_PREDICATE, last_string);
      }
    else
      STRING_1GROW ('}');
  }
	YY_BREAK

/*--------------------------------------------------------------.
  | Scanning some prologue: from "%{" (already scanned) to "%}".  |
  `--------------------------------------------------------------*/


case 129:
YY_RULE_SETUP
#line 817 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_FINISH ();
    loc->start = code_start;
    BEGIN INITIAL;
    RETURN_VALUE (PROLOGUE, last_string);
  }
	YY_BREAK
case YY_STATE_EOF(SC_PROLOGUE):
#line 824 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_eof (code_start, "%}");
	YY_BREAK

/*---------------------------------------------------------------.
  | Scanning the epilogue (everything after the second "%%", which |
  | has already been eaten).                                       |
  `---------------------------------------------------------------*/


case YY_STATE_EOF(SC_EPILOGUE):
#line 835 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_FINISH ();
    loc->start = code_start;
    BEGIN INITIAL;
    RETURN_VALUE (EPILOGUE, last_string);
  }
	YY_BREAK

/*-----------------------------------------------------.
  | By default, grow the string obstack with the input.  |
  `-----------------------------------------------------*/


/* Accept multibyte characters in one block instead of byte after
     byte, so that add_column_width and mbsnwidth can compute correct
     screen width.

     Add a fallthrough "|." so that non UTF-8 input is still accepted
     and does not jam the scanner.  */
case 130:
/* rule 130 can match eol */
YY_RULE_SETUP
#line 856 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW ();
	YY_BREAK

case 131:
YY_RULE_SETUP
#line 859 "/Users/akim/src/gnu/bison/src/scan-gram.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 3038 "src/scan-gram.c"
case YY_STATE_EOF(SC_RETURN_BRACKETED_ID):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
/* %if-c-only */
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
/* %endif */
/* %if-c++-only */
/* %endif */
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
/* %% [14.0] code to do back-up for compressed tables and set up yy_cp goes here */
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */
/* %ok-for-header */

/* %if-c++-only */
/* %not-for-header */
/* %ok-for-header */

/* %endif */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
/* %if-c-only */
static int yy_get_next_buffer (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

/* %if-c-only */
/* %not-for-header */
    static yy_state_type yy_get_previous_state (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
/* %% [15.0] code to get the start state into yy_current_state goes here */
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
/* %% [16.0] code to find the next state goes here */
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 74);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 606 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
/* %if-c-only */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
/* %endif */
/* %if-c++-only */
/* %endif */
{
	int yy_is_jam;
    /* %% [17.0] code to find the next state, and perhaps do backing up, goes here */
	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 74;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 606 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 605);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT
/* %if-c-only */

    static void yyunput (int c, char * yy_bp )
/* %endif */
/* %if-c++-only */
/* %endif */
{
	char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = (yy_n_chars) + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

/* %% [18.0] update yylineno here */

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}
/* %if-c-only */

/* %endif */
#endif

/* %if-c-only */
#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

/* %endif */
/* %if-c++-only */
/* %endif */
{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

/* %% [19.0] update BOL and yylineno */
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
/* %if-c-only */
#endif	/* ifndef YY_NO_INPUT */
/* %endif */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
/* %if-c-only */
    void yyrestart  (FILE * input_file )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/* %if-c++-only */
/* %endif */

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
/* %if-c-only */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

/* %if-c-only */
static void yy_load_buffer_state  (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
/* %if-c-only */
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
/* %endif */
/* %if-c++-only */
/* %endif */
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
/* %if-c-only */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
/* %endif */
/* %if-c++-only */
/* %endif */
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/* %if-c++-only */
/* %endif */

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
/* %if-c-only */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
/* %if-c-only */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )
/* %endif */
/* %if-c++-only */
/* %endif */

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

/* %if-c-only */
	b->yy_input_file = file;
/* %endif */
/* %if-c++-only */
/* %endif */
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

/* %if-c-only */

        b->yy_is_interactive = 0;
    
/* %endif */
/* %if-c++-only */
/* %endif */
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
/* %if-c-only */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/* %if-c-or-c++ */
/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
/* %if-c-only */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}
/* %endif */

/* %if-c-or-c++ */
/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
/* %if-c-only */
void yypop_buffer_state (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}
/* %endif */

/* %if-c-or-c++ */
/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
/* %if-c-only */
static void yyensure_buffer_stack (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}
/* %endif */

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

/* %if-c-only */
static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}
/* %endif */
/* %if-c++-only */
/* %endif */

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/* %if-c-only */
/* %if-reentrant */
/* %endif */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/* %if-reentrant */
/* %endif */

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

/* %endif */

/* %if-reentrant */
/* %if-bison-bridge */
/* %endif */
/* %endif if-c-only */

/* %if-c-only */
static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}
/* %endif */

/* %if-c-only SNIP! this currently causes conflicts with the c++ scanner */
/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

/* %if-reentrant */
/* %endif */
    return 0;
}
/* %endif */

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

/* %if-tables-serialization definitions */
/* %define-yytables   The name for this specific scanner's tables. */
#define YYTABLES_NAME "yytables"
/* %endif */

/* %ok-for-header */

#line 859 "/Users/akim/src/gnu/bison/src/scan-gram.l"



/*------------------------------------------------------.
| Scan NUMBER for a base-BASE integer at location LOC.  |
`------------------------------------------------------*/

static int
scan_integer (char const *number, int base, location loc)
{
  verify (INT_MAX < ULONG_MAX);
  if (base == 16)
    complain (&loc, Wyacc,
              _("POSIX Yacc does not support hexadecimal literals"));

  errno = 0;
  long num = strtol (number, NULL, base);

  if (! (0 <= num && num <= INT_MAX && errno == 0))
    {
      complain (&loc, complaint, _("integer out of range: %s"),
                quote (number));
      num = INT_MAX;
    }

  return num;
}


/*------------------------------------------------------------------.
| Convert universal character name UCN to a single-byte character,  |
| and return that character.  Return -1 if UCN does not correspond  |
| to a single-byte character.                                       |
`------------------------------------------------------------------*/

static int
convert_ucn_to_byte (char const *ucn)
{
  verify (UCHAR_MAX <= INT_MAX);
  long code = strtol (ucn + 2, NULL, 16);

  /* FIXME: Currently we assume Unicode-compatible unibyte characters
     on ASCII hosts (i.e., Latin-1 on hosts with 8-bit bytes).  On
     non-ASCII hosts we support only the portable C character set.
     These limitations should be removed once we add support for
     multibyte characters.  */

  if (! (0 <= code && code <= UCHAR_MAX))
    return -1;

#if ! ('$' == 0x24 && '@' == 0x40 && '`' == 0x60 && '~' == 0x7e)
  {
    /* A non-ASCII host.  Use CODE to index into a table of the C
       basic execution character set, which is guaranteed to exist on
       all Standard C platforms.  This table also includes '$', '@',
       and '`', which are not in the basic execution character set but
       which are unibyte characters on all the platforms that we know
       about.  */
    static signed char const table[] =
      {
        '\0',   -1,   -1,   -1,   -1,   -1,   -1, '\a',
        '\b', '\t', '\n', '\v', '\f', '\r',   -1,   -1,
          -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
          -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
         ' ',  '!',  '"',  '#',  '$',  '%',  '&', '\'',
         '(',  ')',  '*',  '+',  ',',  '-',  '.',  '/',
         '0',  '1',  '2',  '3',  '4',  '5',  '6',  '7',
         '8',  '9',  ':',  ';',  '<',  '=',  '>',  '?',
         '@',  'A',  'B',  'C',  'D',  'E',  'F',  'G',
         'H',  'I',  'J',  'K',  'L',  'M',  'N',  'O',
         'P',  'Q',  'R',  'S',  'T',  'U',  'V',  'W',
         'X',  'Y',  'Z',  '[', '\\',  ']',  '^',  '_',
         '`',  'a',  'b',  'c',  'd',  'e',  'f',  'g',
         'h',  'i',  'j',  'k',  'l',  'm',  'n',  'o',
         'p',  'q',  'r',  's',  't',  'u',  'v',  'w',
         'x',  'y',  'z',  '{',  '|',  '}',  '~'
      };

    code = code < sizeof table ? table[code] : -1;
  }
#endif

  return code;
}


/*----------------------------------------------------------------------------.
| Handle '#line INT_LITERAL( "FILE")?\n'.  ARGS has already skipped '#line '. |
`----------------------------------------------------------------------------*/

static void
handle_syncline (char *args, location loc)
{
  char *file;
  errno = 0;
  long lineno = strtol (args, &file, 10);
  if (! (0 <= lineno && lineno <= INT_MAX && errno == 0))
    {
      complain (&loc, Wother, _("line number overflow"));
      lineno = INT_MAX;
    }

  file = strchr (file, '"');
  if (file)
    {
      *strchr (file + 1, '"') = '\0';
      current_file = uniqstr_new (file + 1);
    }
  boundary_set (&scanner_cursor, current_file, lineno, 1, 1);
}


/*----------------------------------------------------------------.
| For a token or comment starting at START, report message MSGID, |
| which should say that an end marker was found before the        |
| expected TOKEN_END. Then, pretend that TOKEN_END was found.     |
`----------------------------------------------------------------*/

static void
unexpected_end (boundary start, char const *msgid, char const *token_end)
{
  location loc;
  loc.start = start;
  loc.end = scanner_cursor;
  size_t i = strlen (token_end);

  /* Adjust scanner cursor so that any later message does not count
     the characters about to be inserted.  */
  scanner_cursor.column -= i;
  scanner_cursor.byte -= i;

  while (i != 0)
    unput (token_end[--i]);

  token_end = quote (token_end);
  /* Instead of '\'', display "'".  */
  if (STREQ (token_end, "'\\''"))
    token_end = "\"'\"";
  complain (&loc, complaint, msgid, token_end);
}


/*------------------------------------------------------------------------.
| Report an unexpected EOF in a token or comment starting at START.       |
| An end of file was encountered and the expected TOKEN_END was missing.  |
| After reporting the problem, pretend that TOKEN_END was found.          |
`------------------------------------------------------------------------*/

static void
unexpected_eof (boundary start, char const *token_end)
{
  unexpected_end (start, _("missing %s at end of file"), token_end);
}


/*----------------------------------------.
| Likewise, but for unexpected newlines.  |
`----------------------------------------*/

static void
unexpected_newline (boundary start, char const *token_end)
{
  unexpected_end (start, _("missing %s at end of line"), token_end);
}


void
gram_scanner_open (const char *gram)
{
  gram__flex_debug = trace_flag & trace_scan;
  gram_debug = trace_flag & trace_parse;
  obstack_init (&obstack_for_string);
  current_file = gram;
  gram_in = xfopen (gram, "r");
}


void
gram_scanner_close (void)
{
  xfclose (gram_in);
  /* Reclaim Flex's buffers.  */
  yylex_destroy ();
}


void
gram_scanner_free (void)
{
  obstack_free (&obstack_for_string, 0);
}

